Dx12Compiler

Enum Dx12Compiler 

pub enum Dx12Compiler {
    Fxc,
    DynamicDxc {
        dxc_path: String,
    },
    StaticDxc,
    Auto,
}
Selects which DX12 shader compiler to use.

Variants



Fxc

The Fxc compiler (default) is old, slow and unmaintained.

However, it doesn’t require any additional .dlls to be shipped with the application.



DynamicDxc

The Dxc compiler is new, fast and maintained.

However, it requires dxcompiler.dll to be shipped with the application. These files can be downloaded from https://github.com/microsoft/DirectXShaderCompiler/releases.

Minimum supported version: v1.8.2502

It also requires WDDM 2.1 (Windows 10 version 1607).

Fields

dxc_path: String

Path to dxcompiler.dll.



StaticDxc

The statically-linked variant of Dxc.

The static-dxc feature is required for this setting to be used successfully on DX12. Not available on windows-aarch64-pc-* targets.



Auto

Use statically-linked DXC if available. Otherwise check for dynamically linked DXC on the PATH. Finally, fallback to FXC.

Implementations

Source

impl Dx12Compiler

pub const fn default() -> Self

This function is identical to Default::default() except that it is a const fn.

Source

impl Dx12Compiler

pub fn default_dynamic_dxc() -> Self

Helper function to construct a DynamicDxc variant with default paths.

The dll must support at least shader model 6.8.

pub fn from_env() -> Option<Self>

Choose which DX12 shader compiler to use from the environment variable WGPU_DX12_COMPILER.

Valid values, case insensitive:

  • Fxc
  • Dxc or DynamicDxc
  • StaticDxc
pub fn with_env(self) -> Self

Takes the given compiler, modifies it based on the WGPU_DX12_COMPILER environment variable, and returns the result.

See from_env for more information.