pub enum Dx12UseFrameLatencyWaitableObject {
None,
Wait,
DontWait,
}Expand description
Whether and how to use a waitable handle obtained from GetFrameLatencyWaitableObject.
Variants
None
Do not obtain a waitable handle and do not wait for it. The swapchain will
be created without the DXGI_SWAP_CHAIN_FLAG_FRAME_LATENCY_WAITABLE_OBJECT flag.
Wait
Obtain a waitable handle and wait for it before acquiring the next swapchain image.
DontWait
Create the swapchain with the DXGI_SWAP_CHAIN_FLAG_FRAME_LATENCY_WAITABLE_OBJECT flag and
obtain a waitable handle, but do not wait for it before acquiring the next swapchain image.
This is useful if the application wants to wait for the waitable object itself.
Implementations
Sourceimpl Dx12UseFrameLatencyWaitableObject
impl Dx12UseFrameLatencyWaitableObject
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function is identical to Default::default() except that it is a const fn.