pub struct Dx12BackendOptions {
pub shader_compiler: Dx12Compiler,
pub presentation_system: Dx12SwapchainKind,
pub latency_waitable_object: Dx12UseFrameLatencyWaitableObject,
pub force_shader_model: ForceShaderModelToken,
pub agility_sdk: Option<Dx12AgilitySDK>,
}Expand description
Configuration for the DX12 backend.
Part of BackendOptions.
Fields
shader_compiler: Dx12CompilerWhich DX12 shader compiler to use.
presentation_system: Dx12SwapchainKindPresentation system to use.
latency_waitable_object: Dx12UseFrameLatencyWaitableObjectWhether to wait for the latency waitable object before acquiring the next swapchain image.
force_shader_model: ForceShaderModelTokenFor use with passthrough shaders. Expose features as if this shader model is present, even if you do not intend to ship DXC with your app.
This does not override the device’s shader model version, only the external shader compiler’s version.
agility_sdk: Option<Dx12AgilitySDK>Optional Agility SDK configuration for using the Independent Devices API.
When set, wgpu will attempt to load the specified D3D12 runtime via the Independent Devices API. If the API is unavailable or the configuration is invalid, it falls back to the system-installed D3D12 runtime.
Can also be set via WGPU_DX12_AGILITY_SDK_PATH and WGPU_DX12_AGILITY_SDK_VERSION
environment variables.
Implementations
Sourceimpl Dx12BackendOptions
impl Dx12BackendOptions
Sourcepub fn from_env_or_default() -> Self
pub fn from_env_or_default() -> Self
Choose DX12 backend options by calling from_env on every field.
See those methods for more information.