Utf16SourceLocation

Struct Utf16SourceLocation 

pub struct Utf16SourceLocation {
    pub line_number: u32,
    pub line_position: u32,
    pub offset: u32,
    pub length: u32,
}
A human-readable representation for a span, tailored for text source.

Corresponds to the positional members of GPUCompilationMessage from the WebGPU specification.

Unlike SourceLocation, which uses UTF-8 units as a convenience for the wgpu Rust API, this struct locates the span using UTF-16 code units, just like the WebGPU specification.

Fields

line_number: u32

1-based line number.

line_position: u32

1-based column in UTF-16 code units of the start of the span. Remember to convert accordingly when displaying to the user.

offset: u32

0-based offset in UTF-16 code units of the start of the span.

length: u32

Length in UTF-16 code units of the span.

Implementations

Source

impl Utf16SourceLocation

pub fn to_utf8(&self, source: &str) -> SourceLocation

Converts a SourceLocation in UTF-16 code units to UTF-8 code units.