pub enum AccelerationStructureType {
Triangles,
AABBs,
Instances,
}Expand description
What type the data of an acceleration structure is
Variants
Triangles
The types of the acceleration structure are triangles
AABBs
The types of the acceleration structure are axis aligned bounding boxes
Instances
The types of the acceleration structure are instances