pub enum ComponentSwizzle {
Zero,
One,
R,
G,
B,
A,
}Expand description
Specifies the component swizzle for a channel.
Used in TextureComponentSwizzle
Variants
Zero
Force its value to 0.
One
Force its value to 1.
R
Take its value from the red channel of the texture.
G
Take its value from the green channel of the texture.
B
Take its value from the blue channel of the texture.
A
Take its value from the alpha channel of the texture.