#[repr(C)]pub enum FrontFace {
Ccw = 0,
Cw = 1,
}Expand description
Vertex winding order which classifies the “front” face of a triangle.
Corresponds to WebGPU GPUFrontFace.
Variants
Ccw = 0
Triangles with vertices in counter clockwise order are considered the front face.
This is the default with right handed coordinate spaces.
Cw = 1
Triangles with vertices in clockwise order are considered the front face.
This is the default with left handed coordinate spaces.