pub enum PollError {
Timeout,
WrongSubmissionIndex(u64, u64),
}Expand description
Error states after a device poll.
Variants
Timeout
The requested Wait timed out before the submission was completed.
WrongSubmissionIndex(u64, u64)
The requested Wait was given a wrong submission index.