#[repr(C)]pub enum SamplerBindingType {
Filtering = 0,
NonFiltering = 1,
Comparison = 2,
}Expand description
Specific type of a sampler binding.
For use in BindingType::Sampler.
Corresponds to WebGPU GPUSamplerBindingType.
Variants
Filtering = 0
The sampling result is produced based on more than a single color sample from a texture, e.g. when bilinear interpolation is enabled.
NonFiltering = 1
The sampling result is produced based on a single color sample from a texture.
Comparison = 2
Use as a comparison sampler instead of a normal sampler. For more info take a look at the analogous functionality in OpenGL: https://www.khronos.org/opengl/wiki/Sampler_Object#Comparison_mode.