pub struct AdapterLimitBucketInfo {
pub name: Cow<'static, str>,
pub raw_limits: Limits,
pub raw_features: Features,
pub raw_subgroup_min_size: u32,
pub raw_subgroup_max_size: u32,
}Expand description
Information about the applied limit bucket, present in the limit_bucket field
of AdapterInfo when limit bucketing is requested.
Fields
name: Cow<'static, str>The name of the assigned bucket.
No guarantee is made about the format or stability of the bucket names. This should only be used for diagnostic purposes.
raw_limits: LimitsThe adapter’s original limits, before bucketing was applied.
raw_features: FeaturesThe adapter’s original features, before bucketing was applied.
raw_subgroup_min_size: u32The adapter’s original subgroup_min_size, before bucketing was applied.
raw_subgroup_max_size: u32The adapter’s original subgroup_max_size, before bucketing was applied.