#[repr(transparent)]pub struct BufferUsagesWebGPU(<BufferUsagesWebGPU as PublicFlags>::Internal);Expand description
Buffer usages that are defined in the WebGPU specification.
For all usages, see BufferUsages.
Corresponds to WebGPU GPUBufferUsage.
Tuple Fields
0: <BufferUsagesWebGPU as PublicFlags>::InternalImplementations
Sourceimpl BufferUsagesWebGPU
impl BufferUsagesWebGPU
Sourcepub const MAP_READ: Self
pub const MAP_READ: Self
Allow a buffer to be mapped for reading using Buffer::map_async + Buffer::get_mapped_range.
This does not include creating a buffer with BufferDescriptor::mapped_at_creation set.
If Features::MAPPABLE_PRIMARY_BUFFERS isn’t enabled, the only other usage a buffer
may have is COPY_DST.
Sourcepub const MAP_WRITE: Self
pub const MAP_WRITE: Self
Allow a buffer to be mapped for writing using Buffer::map_async + Buffer::get_mapped_range_mut.
This does not include creating a buffer with BufferDescriptor::mapped_at_creation set.
If Features::MAPPABLE_PRIMARY_BUFFERS feature isn’t enabled, the only other usage a buffer
may have is COPY_SRC.
Sourcepub const COPY_SRC: Self
pub const COPY_SRC: Self
Allow a buffer to be the source buffer for a CommandEncoder::copy_buffer_to_buffer or CommandEncoder::copy_buffer_to_texture
operation.
Sourcepub const COPY_DST: Self
pub const COPY_DST: Self
Allow a buffer to be the destination buffer for a CommandEncoder::copy_buffer_to_buffer, CommandEncoder::copy_texture_to_buffer,
CommandEncoder::clear_buffer or Queue::write_buffer operation.
Sourcepub const UNIFORM: Self
pub const UNIFORM: Self
Allow a buffer to be a BufferBindingType::Uniform inside a bind group.
Sourcepub const STORAGE: Self
pub const STORAGE: Self
Allow a buffer to be a BufferBindingType::Storage inside a bind group.
Sourcepub const QUERY_RESOLVE: Self
pub const QUERY_RESOLVE: Self
Allow a buffer to be the destination buffer for a CommandEncoder::resolve_query_set operation.
Sourceimpl BufferUsagesWebGPU
impl BufferUsagesWebGPU
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl BufferUsagesWebGPU
impl BufferUsagesWebGPU
Sourcepub const fn iter(&self) -> Iter<BufferUsagesWebGPU>
pub const fn iter(&self) -> Iter<BufferUsagesWebGPU>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BufferUsagesWebGPU>
pub const fn iter_names(&self) -> IterNames<BufferUsagesWebGPU>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.