#[repr(C)]
pub struct DeviceDescriptor<L> { pub label: L, pub features: Features, pub limits: Limits, }
Describes a Device.

Corresponds to WebGPU GPUDeviceDescriptor.

Fields

label: L

Debug label for the device.

features: Features

Features that the device should support. If any feature is not supported by the adapter, creating a device will panic.

limits: Limits

Limits that the device should support. If any limit is “better” than the limit exposed by the adapter, creating a device will panic.

Implementations

Takes a closure and maps the label of the device descriptor into another.