#[repr(C)]pub struct ImageSubresourceRange {
pub aspect: TextureAspect,
pub base_mip_level: u32,
pub mip_level_count: Option<u32>,
pub base_array_layer: u32,
pub array_layer_count: Option<u32>,
}Expand description
Subresource range within an image
Fields
aspect: TextureAspectAspect of the texture. Color textures must be TextureAspect::All.
base_mip_level: u32Base mip level.
mip_level_count: Option<u32>Mip level count.
If Some(count), base_mip_level + count must be less or equal to underlying texture mip count.
If None, considered to include the rest of the mipmap levels, but at least 1 in total.
base_array_layer: u32Base array layer.
array_layer_count: Option<u32>Layer count.
If Some(count), base_array_layer + count must be less or equal to the underlying array count.
If None, considered to include the rest of the array layers, but at least 1 in total.
Implementations
Sourceimpl ImageSubresourceRange
impl ImageSubresourceRange
Sourcepub fn is_full_resource(
&self,
format: TextureFormat,
mip_levels: u32,
array_layers: u32,
) -> bool
pub fn is_full_resource( &self, format: TextureFormat, mip_levels: u32, array_layers: u32, ) -> bool
Returns if the given range represents a full resource, with a texture of the given layer count and mip count.
let range_none = wgpu::ImageSubresourceRange {
aspect: wgpu::TextureAspect::All,
base_mip_level: 0,
mip_level_count: None,
base_array_layer: 0,
array_layer_count: None,
};
assert_eq!(range_none.is_full_resource(wgpu::TextureFormat::Stencil8, 5, 10), true);
let range_some = wgpu::ImageSubresourceRange {
aspect: wgpu::TextureAspect::All,
base_mip_level: 0,
mip_level_count: Some(5),
base_array_layer: 0,
array_layer_count: Some(10),
};
assert_eq!(range_some.is_full_resource(wgpu::TextureFormat::Stencil8, 5, 10), true);
let range_mixed = wgpu::ImageSubresourceRange {
aspect: wgpu::TextureAspect::StencilOnly,
base_mip_level: 0,
// Only partial resource
mip_level_count: Some(3),
base_array_layer: 0,
array_layer_count: None,
};
assert_eq!(range_mixed.is_full_resource(wgpu::TextureFormat::Stencil8, 5, 10), false);Trait Implementations
Sourceimpl Clone for ImageSubresourceRange
impl Clone for ImageSubresourceRange
Sourcefn clone(&self) -> ImageSubresourceRange
fn clone(&self) -> ImageSubresourceRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ImageSubresourceRange
Sourceimpl Debug for ImageSubresourceRange
impl Debug for ImageSubresourceRange
Sourceimpl Default for ImageSubresourceRange
impl Default for ImageSubresourceRange
Sourcefn default() -> ImageSubresourceRange
fn default() -> ImageSubresourceRange
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ImageSubresourceRange
Available on crate feature serde only.
impl<'de> Deserialize<'de> for ImageSubresourceRange
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ImageSubresourceRange
Sourceimpl PartialEq for ImageSubresourceRange
impl PartialEq for ImageSubresourceRange
Sourceimpl Serialize for ImageSubresourceRange
Available on crate feature serde only.
impl Serialize for ImageSubresourceRange
Available on crate feature
serde only.impl StructuralPartialEq for ImageSubresourceRange