TextureComponentSwizzle

Struct TextureComponentSwizzle 

pub struct TextureComponentSwizzle {
    pub r: ComponentSwizzle,
    pub g: ComponentSwizzle,
    pub b: ComponentSwizzle,
    pub a: ComponentSwizzle,
}
Specifies the texture component swizzle for each channel.

Used in TextureViewDescriptor::swizzle.

Example:

// The swizzle maps `xgxr` to `rg01`, or maps `rgba` to `ag01`
TextureComponentSwizzle {
    r: ComponentSwizzle::A,
    g: ComponentSwizzle::G,
    b: ComponentSwizzle::Zero,
    a: ComponentSwizzle::One,
};

Fields

r: ComponentSwizzle

Replace the red channel with the ComponentSwizzle.

g: ComponentSwizzle

Replace the green channel with the ComponentSwizzle.

b: ComponentSwizzle

Replace the blue channel with the ComponentSwizzle.

a: ComponentSwizzle

Replace the alpha channel with the ComponentSwizzle.

Implementations

Source

impl TextureComponentSwizzle

fn select(&self, component: ComponentSwizzle) -> ComponentSwizzle

pub fn compose(&self, other: Self) -> Self

Computes a swizzle that when applied, is equivalent to applying self then other, like the order of WGSL swizzles (value.rgba.rgba).