#[repr(C)]pub enum SurfaceStatus {
Good = 0,
Suboptimal = 1,
Timeout = 2,
Occluded = 3,
Outdated = 4,
Lost = 5,
Validation = 6,
}Expand description
Status of the received surface image.
Variants
Good = 0
No issues.
Suboptimal = 1
The swap chain is operational, but it does no longer perfectly match the surface. A re-configuration is needed.
Timeout = 2
Unable to get the next frame, timed out.
Try reconfiguring your surface.
Occluded = 3
The window is occluded (e.g. minimized or behind another window).
Try again once the window is no longer occluded.
Outdated = 4
The surface under the swap chain has changed.
Try reconfiguring your surface.
Lost = 5
The surface under the swap chain is lost.
Validation = 6
Surface::get_current_texture has hit a validation error which was caught
by a error scope.