pub struct Operations<V> {
pub load: LoadOp<V>,
pub store: StoreOp,
}Expand description
Pair of load and store operations for an attachment aspect.
This type is unique to the Rust API of wgpu. In the WebGPU specification,
separate loadOp and storeOp fields are used instead.
Fields
load: LoadOp<V>How data should be read through this attachment.
store: StoreOpWhether data will be written to through this attachment.
Note that resolve textures (if specified) are always written to, regardless of this setting.